@@ -17,9 +17,10 @@ use URI::URL;
 
 use feature 'state';
 
-extends 'Lemonldap::NG::Common::Conf::RESTServer';
+extends 'Lemonldap::NG::Manager::Plugin',
+  'Lemonldap::NG::Common::Conf::RESTServer';
 
-our $VERSION = '2.0.0';
+our $VERSION = '2.0.9';
 
 #############################
 # I. INITIALIZATION METHODS #
@@ -29,7 +30,7 @@ use constant defaultRoute => 'manager.html';
 
 has ua => ( is => 'rw' );
 
-sub addRoutes {
+sub init {
     my ( $self, $conf ) = @_;
     $self->ua( Lemonldap::NG::Common::UserAgent->new($conf) );
 
@@ -44,7 +45,7 @@ sub addRoutes {
                 qw(virtualHosts samlIDPMetaDataNodes samlSPMetaDataNodes
                   applicationList oidcOPMetaDataNodes oidcRPMetaDataNodes
                   casSrvMetaDataNodes casAppMetaDataNodes
-                  authChoiceModules grantSessionRules combModules
+                  authChoiceModules grantSessionRules combModules sfExtra
                   openIdIDPList)
             ]
         },
@@ -56,8 +57,11 @@ sub addRoutes {
 
       # New key and conf save
       ->addRoute(
-        confs =>
-          { newRSAKey => 'newRSAKey', raw => 'newRawConf', '*' => 'newConf' },
+        confs => {
+            newRSAKey => 'newRSAKey',
+            raw       => 'newRawConf',
+            '*'       => 'newConf'
+        },
         ['POST']
       )
 
@@ -67,6 +71,7 @@ sub addRoutes {
 
       # Url loader
       ->addRoute( 'prx', undef, ['POST'] );
+    return 1;
 }
 
 # 35 - New RSA key pair on demand
@@ -154,7 +159,7 @@ sub prx {
 #  - getConfByNum: override SUPER method to be able to use Zero
 #  - newConf()
 #  - newRawConf(): restore a saved conf
-#  - applyConf(): called by the 2 previous to prevent other servers that a new
+#  - applyConf(): called by the 2 previous to inform other servers that a new
 #                 configuration is available
 
 sub getConfByNum {
@@ -224,26 +229,34 @@ sub newConf {
 
     if ( $cfgNum ne $req->params('cfgNum') ) { $parser->confChanged(1); }
 
-    my $res = { result => $parser->check };
+    my $res = { result => $parser->check($self->p) };
 
     # "message" fields: note that words enclosed by "__" (__word__) will be
     # translated
-    $res->{message} = $parser->{message};
-    foreach my $t (qw(errors warnings changes)) {
-        $res->{details}->{ '__' . $t . '__' } = $parser->$t
-          if ( @{ $parser->$t } );
+    $res->{details}->{'__errors__'} = $parser->{errors}
+      if ( @{ $parser->{errors} } );
+    unless ( @{ $parser->{errors} } ) {
+        $res->{details}->{'__needConfirmation__'} = $parser->{needConfirmation}
+          if ( @{ $parser->{needConfirmation} } && !$req->params('force') );
+        $res->{message} = $parser->{message};
+        foreach my $t (qw(warnings changes)) {
+            $res->{details}->{ '__' . $t . '__' } = $parser->$t
+              if ( @{ $parser->$t } );
+        }
     }
     if ( $res->{result} ) {
-        if ( $self->{demoMode} ) {
+        if ( $self->p->{demoMode} ) {
             $res->{message} = '__demoModeOn__';
         }
         else {
             my %args;
             $args{force} = 1 if ( $req->params('force') );
-            my $s = $self->confAcc->saveConf( $parser->newConf, %args );
+            my $s = CONFIG_WAS_CHANGED;
+            $s = $self->confAcc->saveConf( $parser->newConf, %args )
+              unless ( @{ $parser->{needConfirmation} } && !$args{force} );
             if ( $s > 0 ) {
                 $self->userLogger->notice(
-                    'User ' . $self->userId($req) . " has stored conf $s" );
+                    'User ' . $self->p->userId($req) . " has stored conf $s" );
                 $res->{result} = 1;
                 $res->{cfgNum} = $s;
                 if ( my $status = $self->applyConf( $parser->newConf ) ) {
@@ -255,11 +268,12 @@ sub newConf {
             else {
                 $self->userLogger->notice(
                     'Saving attempt rejected, asking for confirmation to '
-                      . $self->userId($req) );
+                      . $self->p->userId($req) );
                 $res->{result} = 0;
                 if ( $s == CONFIG_WAS_CHANGED ) {
                     $res->{needConfirm} = 1;
-                    $res->{message} .= '__needConfirmation__';
+                    $res->{message} .= '__needConfirmation__'
+                      unless @{ $parser->{needConfirmation} };
                 }
                 else {
                     $res->{message} = $Lemonldap::NG::Common::Conf::msg;
@@ -287,7 +301,7 @@ sub newRawConf {
     }
 
     my $res = {};
-    if ( $self->{demoMode} ) {
+    if ( $self->p->{demoMode} ) {
         $res->{message} = '__demoModeOn__';
     }
     else {
@@ -295,16 +309,17 @@ sub newRawConf {
         # chances to be equal to last config cfgNum
         my $s = $self->confAcc->saveConf( $new, force => 1 );
         if ( $s > 0 ) {
-            $self->userLogger->notice(
-                'User ' . $self->userId($req) . " has stored (raw) conf $s" );
+            $self->userLogger->notice( 'User '
+                  . $self->p->userId($req)
+                  . " has stored (raw) conf $s" );
             $res->{result} = 1;
             $res->{cfgNum} = $s;
         }
         else {
             $self->userLogger->notice(
                 'Raw saving attempt rejected, asking for confirmation to '
-                  . $self->userId($req) );
-            $res->{result} = 0;
+                  . $self->p->userId($req) );
+            $res->{result}      = 0;
             $res->{needConfirm} = 1 if ( $s == CONFIG_WAS_CHANGED );
             $res->{message} .= '__needConfirmation__';
         }
@@ -313,7 +328,7 @@ sub newRawConf {
 }
 
 ## @method private applyConf()
-# Try to prevent other servers declared in `reloadUrls` that a new
+# Try to inform other servers declared in `reloadUrls` that a new
 # configuration is available.
 #
 #@return reload status as boolean
@@ -322,7 +337,7 @@ sub applyConf {
     my $status;
 
     # 1 Apply conf locally
-    $self->api->checkConf();
+    $self->p->api->checkConf();
 
     # Get apply section values
     my %reloadUrls =
@@ -337,6 +352,7 @@ sub applyConf {
     # Parse apply values
     while ( my ( $host, $request ) = each %reloadUrls ) {
         my $r = HTTP::Request->new( 'GET', "http://$host$request" );
+        $self->logger->debug("Sending reload request to $host");
         if ( $request =~ /^https?:\/\/[^\/]+.*$/ ) {
             my $url       = URI::URL->new($request);
             my $targetUrl = $url->scheme . "://" . $host;
@@ -345,7 +361,8 @@ sub applyConf {
             $r =
               HTTP::Request->new( 'GET', $targetUrl,
                 HTTP::Headers->new( Host => $url->host ) );
-            if ( defined $url->userinfo && $url->userinfo =~ /^([^:]+):(.*)$/ )
+            if ( defined $url->userinfo
+                && $url->userinfo =~ /^([^:]+):(.*)$/ )
             {
                 $r->authorization_basic( $1, $2 );
             }
