@@ -3,8 +3,9 @@ package Lemonldap::NG::Manager::Conf::Tests;
 use utf8;
 use Lemonldap::NG::Common::Regexp;
 use Lemonldap::NG::Handler::Main;
+use Lemonldap::NG::Common::Util qw(getSameSite);
 
-our $VERSION = '2.0.8';
+our $VERSION = '2.0.9';
 
 ## @method hashref tests(hashref conf)
 # Return a hash ref where keys are the names of the tests and values
@@ -225,7 +226,7 @@ sub tests {
             eval { tied(%h)->delete; };
             return ( -1, "Unable to delete session ($@)" ) if ($@);
             return ( -1,
-'All sessions may be lost and you must restart all your Apache servers'
+'All sessions may be lost and you must restart all your web servers'
             ) if ( $gc and $conf->{globalStorage} ne $gc );
             return 1;
         },
@@ -253,8 +254,6 @@ sub tests {
             return ( 1, "Cookie TTL should be higher or equal than one hour" )
               unless ( $conf->{cookieExpiration} >= 3600
                 || $conf->{cookieExpiration} == 0 );
-
-            # Return
             return 1;
         },
 
@@ -264,8 +263,6 @@ sub tests {
             return ( -1, "Session timeout should be higher than ten minutes" )
               unless ( $conf->{timeout} > 600
                 || $conf->{timeout} == 0 );
-
-            # Return
             return 1;
         },
 
@@ -277,8 +274,6 @@ sub tests {
               )
               unless ( $conf->{timeoutActivity} > 59
                 || $conf->{timeoutActivity} == 0 );
-
-            # Return
             return 1;
         },
 
@@ -291,8 +286,6 @@ sub tests {
               if (  $conf->{timeoutActivity}
                 and $conf->{timeoutActivity} <=
                 $conf->{timeoutActivityInterval} );
-
-            # Return
             return 1;
         },
 
@@ -337,12 +330,10 @@ sub tests {
             return ( 1, "SMTP authentication failed" )
               unless $smtp->auth( $conf->{SMTPAuthUser},
                 $conf->{SMTPAuthPass} );
-
-            # Return
             return 1;
         },
 
-        # SAML entity ID must be uniq
+        # SAML entity ID must be unique
         samlIDPEntityIdUniqueness => sub {
             return 1
               unless ( $conf->{samlIDPMetaDataXML}
@@ -440,8 +431,6 @@ sub tests {
               unless ( $conf->{combination} );
             return ( 0, 'userDB must be set to "Same" to enable Combination' )
               unless ( $conf->{userDB} eq "Same" );
-
-            # Return
             return 1;
         },
 
@@ -481,8 +470,6 @@ sub tests {
 "Auth::Yubikey_WebClient module is required to enable Yubikey"
                 ) if ($@);
             }
-
-            # Return
             return 1;
         },
 
@@ -520,8 +507,6 @@ sub tests {
               unless ( $conf->{totp2fRange} );
             return ( 1, "TOTP interval should be higher than 10s" )
               unless ( $conf->{totp2fInterval} > 10 );
-
-            # Return
             return 1;
         },
 
@@ -569,7 +554,6 @@ sub tests {
                 || $conf->{'totp2fSelfRegistration'} );
             $msg = "A self registrable module should be enabled to require 2FA"
               unless ($ok);
-
             return ( 1, $msg );
         },
 
@@ -582,8 +566,6 @@ sub tests {
                 return ( 0, "External 2F Validate command must be set" )
                   unless ( defined $conf->{ext2FValidateCommand} );
             }
-
-            # Return
             return 1;
         },
 
@@ -594,8 +576,6 @@ sub tests {
               unless ( $conf->{formTimeout} > 30 );
             return ( 1, "XSRF form token TTL should not be higher than 2mn" )
               if ( $conf->{formTimeout} > 120 );
-
-            # Return
             return 1;
         },
 
@@ -606,8 +586,6 @@ sub tests {
               unless ( $conf->{issuersTimeout} > 30 );
             return ( 1, "Issuers token TTL should not be higher than 2mn" )
               if ( $conf->{issuersTimeout} > 120 );
-
-            # Return
             return 1;
         },
 
@@ -616,21 +594,16 @@ sub tests {
             return 1 unless ( $conf->{portalDisplayResetPassword} );
             return ( 1, "Number of reset password retries should not be null" )
               unless ( $conf->{passwordResetAllowedRetries} );
-
-            # Return
             return 1;
         },
 
         # Warn if ldapPpolicyControl is used with AD (#2007)
-
         ppolicyAd => sub {
-            if (    $conf->{ldapPpolicyControl}
-                and $conf->{authentication} eq "AD" )
-            {
-                return ( 1,
+            return ( 1,
 "LDAP password policy control should be disabled when using AD authentication"
-                );
-            }
+              )
+              if (  $conf->{ldapPpolicyControl}
+                and $conf->{authentication} eq "AD" );
             return 1;
         },
 
@@ -643,8 +616,18 @@ sub tests {
             return ( 1,
 'Number of failed logins must be higher than 2 to enable "BruteForceProtection" plugin'
             ) unless ( $conf->{failedLoginNumber} > 2 );
-
-            # Return
+            return ( 1,
+'Number of failed logins history must be higher than allowed failed logins plus lock time values'
+              )
+              if ( $conf->{bruteForceProtectionIncrementalTempo}
+                && $conf->{failedLoginNumber} <=
+                $conf->{bruteForceProtectionMaxFailed} +
+                $conf->{bruteForceProtectionLockTimes} );
+            return ( 1,
+'Number of failed logins history must be higher than allowed failed logins'
+              )
+              unless ( $conf->{failedLoginNumber} >
+                $conf->{bruteForceProtectionMaxFailed} );
             return 1;
         },
 
@@ -656,8 +639,6 @@ sub tests {
               )
               unless ( $conf->{requireToken}
                 or $conf->{captcha_mail_enabled} );
-
-            # Return
             return 1;
         },
 
@@ -668,8 +649,6 @@ sub tests {
               )
               if ( $conf->{impersonationRule}
                 && $conf->{contextSwitchingRule} );
-
-            # Return
             return 1;
         },
 
@@ -693,8 +672,6 @@ sub tests {
             return ( 1,
 "BruteForceProtection plugin enabled WITHOUT persistent session storage"
             ) if ( $conf->{bruteForceProtection} );
-
-            # Return
             return 1;
         },
 
@@ -709,8 +686,6 @@ sub tests {
             return ( 1,
 "XML::LibXSLT module is required to enable old format notifications"
             ) if ($@);
-
-            # Return
             return 1;
         },
 
@@ -724,8 +699,6 @@ sub tests {
             return ( 1,
 "DateTime::Format::RFC3339 module is required to enable CertificateResetByMail plugin"
             ) if ($@);
-
-            # Return
             return 1;
         },
 
@@ -770,6 +743,71 @@ sub tests {
             return 1;
         },
 
+        # OIDC RP Client ID must exist and be unique
+        oidcRPClientIdUniqueness => sub {
+            return 1
+              unless ( $conf->{oidcRPMetaDataOptions}
+                and %{ $conf->{oidcRPMetaDataOptions} } );
+            my @msg;
+            my $res = 1;
+            my %clientIds;
+            foreach
+              my $clientConfKey ( keys %{ $conf->{oidcRPMetaDataOptions} } )
+            {
+                my $clientId = $conf->{oidcRPMetaDataOptions}->{$clientConfKey}
+                  ->{oidcRPMetaDataOptionsClientID};
+                unless ($clientId) {
+                    push @msg,
+                      "$clientConfKey OIDC Relying Party has no Client ID";
+                    $res = 0;
+                    next;
+                }
+
+                if ( defined $clientIds{$clientId} ) {
+                    push @msg,
+"$clientConfKey and $clientIds{$clientId} have the same Client ID";
+                    $res = 0;
+                    next;
+                }
+                $clientIds{$clientId} = $clientConfKey;
+            }
+            return ( $res, join( ', ', @msg ) );
+        },
+
+        # CAS APP URL must be unique
+        casAppHostnameUniqueness => sub {
+            return 1
+              unless ( $conf->{casAppMetaDataOptions}
+                and %{ $conf->{casAppMetaDataOptions} } );
+            my @msg;
+            my $res = 1;
+            my %casHosts;
+            foreach my $casConfKey ( keys %{ $conf->{casAppMetaDataOptions} } )
+            {
+                my $appUrl =
+                  $conf->{casAppMetaDataOptions}->{$casConfKey}
+                  ->{casAppMetaDataOptionsService}
+                  || "";
+                $appUrl =~ m#^(https?://[^/]+)(/.*)?$#;
+                my $appHost = $1;
+                unless ($appHost) {
+                    push @msg,
+                      "$clientConfKey CAS Application has no Service URL";
+                    $res = 0;
+                    next;
+                }
+
+                if ( defined $casHosts{$appHost} ) {
+                    push @msg,
+"$casConfKey and $casHosts{$appHost} have the same Service hostname";
+                    $res = 0;
+                    next;
+                }
+                $casHosts{$appHost} = $casConfKey;
+            }
+            return ( $res, join( ', ', @msg ) );
+        },
+
         # Notification system required with removed SF notification
         sfRemovedNotification => sub {
             return 1 unless ( $conf->{sfRemovedMsgRule} );
@@ -778,6 +816,32 @@ sub tests {
             ) if ( $conf->{sfRemovedUseNotif} and not $conf->{notification} );
             return 1;
         },
+
+        # noAjaxHook and krbByJs are incompatible (#2237)
+        noAjaxHookwithKrb => sub {
+            return ( 1,
+                    'noAjaxHook is not compatible with'
+                  . ' AJAX Kerberos authentication' )
+              if ( $conf->{noAjaxHook} and $conf->{krbByJs} );
+            return 1;
+        },
+
+        # Cookie SameSite=None requires Secure flag
+        # Same with SameSite=(auto) and SAML issuer in use
+        SameSiteNoneWithSecure => sub {
+            return ( 1, 'SameSite value = None requires the secured flag' )
+              if ( getSameSite($conf) eq 'None' and !$conf->{securedCookie} );
+            return 1;
+        },
+
+        # Secure cookies require HTTPS
+        SecureCookiesRequireHttps => sub {
+            return ( 1, 'Secure cookies require a HTTPS portal URL' )
+              if (  $conf->{securedCookie} == 1
+                and $conf->{portal}
+                and $conf->{portal} !~ /^https:/ );
+            return 1;
+        },
     };
 }
 
